aboutsummaryrefslogtreecommitdiff
path: root/bpkg/pkg-verify.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2018-12-22 22:42:13 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2019-01-15 13:22:50 +0300
commitcbd3cd125b574deaf1ad3c7001c5b6c9c40198ed (patch)
tree924cbe981a3e556dd1511a7397584ef03b53703d /bpkg/pkg-verify.hxx
parentd51aa769a5441ccb5279e2fc4f50b127db0dea84 (diff)
Add support for $ in package manifest dependency constraint
Diffstat (limited to 'bpkg/pkg-verify.hxx')
-rw-r--r--bpkg/pkg-verify.hxx10
1 files changed, 6 insertions, 4 deletions
diff --git a/bpkg/pkg-verify.hxx b/bpkg/pkg-verify.hxx
index a772a8f..73d3c17 100644
--- a/bpkg/pkg-verify.hxx
+++ b/bpkg/pkg-verify.hxx
@@ -19,15 +19,17 @@ namespace bpkg
// Verify archive is a valid package and return its manifest. If requested,
// expand the file-referencing manifest values (description, changes, etc),
// setting them to the contents of files they refer to. Throw failed if
// invalid or if something goes wrong. If diag is false, then don't issue
// diagnostics about the reason why the package is invalid.
//
package_manifest
pkg_verify (const common_options&,
const path& archive,
- bool expand_values,
bool ignore_unknown,
+ bool expand_values,
+ bool complete_depends = true,
bool diag = true);
// Similar to the above but verifies that a source directory is a valid
@@ -19,15 +19,17 @@ namespace bpkg
// Verify archive is a valid package and return its manifest. If requested,
// expand the file-referencing manifest values (description, changes, etc),
- // setting them to the contents of files they refer to. Throw failed if
- // invalid or if something goes wrong. If diag is false, then don't issue
- // diagnostics about the reason why the package is invalid.
+ // setting them to the contents of files they refer to as well as complete
+ // the dependency constraints. Throw failed if invalid or if something goes
+ // wrong. If diag is false, then don't issue diagnostics about the reason
+ // why the package is invalid.
//
package_manifest